import base64

def encrypt(text:str):
    ret = base64.b64encode(bytes(text, encoding='UTF-8'))
    return str(ret, 'UTF-8')

def decrypt(text:str):
    ret = base64.b64decode(bytes(text, encoding='UTF-8'))
    return str(ret, 'UTF-8')


from kafka import KafkaProducer, KafkaConsumer, TopicPartition
from kafka.errors import KafkaTimeoutError
from .mq import Writer, Reader

class KafkaReader(Reader):
    def __init__(self, options):
        self.options = options
        self.consumer = None

    def get_consumer(self):
        if self.consumer==None:
            self.consumer = KafkaConsumer(
                bootstrap_servers       = self.get_option('bootstrap_servers'),
                group_id                = self.get_option('group_id'),
                enable_auto_commit      = self.get_option('enable_auto_commit', True),
                auto_offset_reset       = self.get_option('auto_offset_reset', 'earliest'),
                max_poll_records        = self.get_option('max_poll_records', 500),
                max_poll_interval_ms    = self.get_option('max_poll_interval_ms', 300000),
                max_partition_fetch_bytes = self.get_option('max_partition_fetch_bytes', 1*1024*1024)
            )

        return self.consumer
    
    def run(self, callback):
        consumer = self.get_consumer()

        '''auto_offset_reset
        earliest:表示分区下有已提交的offset时，从提交的offset开始消费；无提交的offset时，从头开始消费；
        latest:表示分区下有已提交的offset时，从提交的offset开始消费；无提交的offset时，消费新产生的该分区下的数据
        '''
        consumer.subscribe( self.get_option('topics') )

        for message in consumer:
            callback(message.value, handler=message, consumer=consumer)

class KafkaWriter(Writer):
    def __init__(self, *, bootstrap_servers, topic, max_request_size=1048576):
        self.topic = topic
        self.producer = KafkaProducer(bootstrap_servers = bootstrap_servers, max_request_size=max_request_size)

    def write(self, message, *, topic=None, callback=None):
        def send_success(*args, **kwargs):
            if callback!=None:
                callback(is_success=True)

        def send_error(*args, **kwargs):
            if callback!=None:
                callback(is_success=False)

        try:
            if topic==None:
                real_topic = self.topic
            else:
                real_topic = topic
                
            self.producer.send(
                real_topic, 
                message
            ).add_callback(send_success).add_errback(send_error)
        except KafkaTimeoutError as k:
            print("发送超时", k)


import unittest
import base64
import datetime
from lantools import minio 

class TestCase(unittest.TestCase):
    def setUp(self):
        self.bucket = "mybucket"
        self.minio = minio.PyMinio(
            '10.10.9.31',
            9000,
            'minioadmin',
            'minioadmin',
        )
        self.minio.set_bucket(self.bucket)

    def tearDown(self):
        pass

    def test_upload_1(self):
        with open("/app/test/file/1.jpeg", "rb") as f:
            content = f.read()

        image_base64=str(base64.b64encode(content),encoding='utf8')

        filename = self.minio.upload_image(image_base64, object_name="test/1.jpeg")

        self.assertEqual(self.minio.exists(filename, trim=True), True)

        self.minio.remove_file(filename, trim=True)

    def test_upload_2(self):
        with open("/app/test/file/1.jpeg", "rb") as f:
            content = f.read()

        image_base64=str(base64.b64encode(content),encoding='utf8')

        filename = self.minio.upload_image(image_base64)

        self.assertEqual(self.minio.exists(filename, trim=True), True)

        self.minio.remove_file(filename, trim=True)

    


import unittest
import base64
import datetime
import lantools

crypt = lantools.crypt

class TestCase(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_1(self):
        self.assertEqual(crypt.encrypt("Hello World"), 'SGVsbG8gV29ybGQ=')

        self.assertEqual(crypt.decrypt('SGVsbG8gV29ybGQ='), "Hello World")

    


import unittest
from lantools import service

class App(service.Service):
    def __init__(self):
        super().__init__()
        self.counter = 0
    
    def _mysql(self):
        self.counter = self.counter + 1
        return "mysql"+ str(self.counter)

    def _logger(self):
        raise Exception("xxx")


class TestCase(unittest.TestCase):
    def setUp(self):
        pass
    def tearDown(self):
        pass

    def test_1(self):
        app = App()

        self.assertEqual(app.mysql, 'mysql1')
        self.assertEqual(app.mysql, 'mysql1')

    def test_2(self):
        app = App()

        self.assertEqual(app.redis, None)

    def test_3(self):
        app = App()

        with self.assertRaises(Exception) as e:
            app.logger

        self.assertEqual(str(e.exception), 'xxx')


